import { defineComponent, ref, computed, onMounted, createBlock, openBlock, Transition, withCtx, withDirectives, createElementVNode, normalizeStyle, normalizeClass, createCommentVNode, createElementBlock, unref, toDisplayString, createVNode, vShow, render } from "vue";
import TOAST_TYPE from "./type.js";
import { a_ as IconInfoToast, a$ as IconErrorToast, aZ as IconWarningToast, b0 as IconSuccessToast, T as TUIIcon, E as IconClose } from "../../index-B3QCMq6W.js";
import { useComponent } from "../hooks/useComponent.js";
const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "index",
  props: {
    customClasses: {
      type: String,
      default: ""
    },
    message: {
      type: String,
      default: ""
    },
    duration: {
      type: Number,
      default: 3e3
    },
    offset: {
      type: Number,
      default: 16
    },
    type: {
      type: String,
      default: TOAST_TYPE.INFO
    },
    onClose: {
      type: Function,
      default: () => {
      }
    },
    showIcon: {
      type: Boolean,
      default: true
    },
    showClose: {
      type: Boolean,
      default: false
    }
  },
  setup(__props) {
    const props = __props;
    const visible = ref(false);
    let timer;
    const { ToastConfig } = useComponent();
    const startTimer = () => {
      if (props.duration > 0) {
        timer = setTimeout(() => {
          if (visible.value) {
            close2();
          }
        }, props.duration);
      }
    };
    const clearTimer = () => {
      timer && clearTimeout(timer);
    };
    const close2 = () => {
      visible.value = false;
      clearTimer();
      if (typeof props.onClose === "function") {
        props.onClose();
      }
    };
    const Icon = computed(() => {
      switch (props.type) {
        case TOAST_TYPE.INFO:
          return IconInfoToast;
        case TOAST_TYPE.SUCCESS:
          return IconSuccessToast;
        case TOAST_TYPE.WARNING:
          return IconWarningToast;
        case TOAST_TYPE.ERROR:
          return IconErrorToast;
        default:
          return IconInfoToast;
      }
    });
    const customStyle = computed(() => ({
      top: `${props.offset}px`,
      zIndex: 9999
    }));
    onMounted(() => {
      clearTimer();
      startTimer();
      visible.value = true;
    });
    const handleStyle = (type) => {
      if (type && (type === TOAST_TYPE.ERROR || type === TOAST_TYPE.SUCCESS || type === TOAST_TYPE.WARNING)) {
        return type;
      }
      return TOAST_TYPE.INFO;
    };
    return (_ctx, _cache) => {
      return openBlock(), createBlock(Transition, {
        name: "fade",
        onAfterLeave: _cache[0] || (_cache[0] = ($event) => _ctx.$emit("destroy"))
      }, {
        default: withCtx(() => [
          withDirectives(createElementVNode("div", {
            class: normalizeClass(["tui-message", handleStyle(__props.type)]),
            style: normalizeStyle(customStyle.value)
          }, [
            __props.showIcon || unref(ToastConfig).showIcon ? (openBlock(), createBlock(unref(TUIIcon), {
              key: 0,
              icon: Icon.value
            }, null, 8, ["icon"])) : createCommentVNode("", true),
            createElementVNode("p", null, toDisplayString(__props.message), 1),
            __props.showClose || unref(ToastConfig).showClose ? (openBlock(), createElementBlock("div", {
              key: 1,
              onClick: close2
            }, [
              createVNode(unref(IconClose), { class: "close-icon" })
            ])) : createCommentVNode("", true)
          ], 6), [
            [vShow, visible.value]
          ])
        ]),
        _: 1
      });
    };
  }
});
const instances = [];
let seed = 1;
const removeToast = function(domId) {
  var _a, _b, _c, _d, _e, _f, _g, _h, _i, _j, _k, _l, _m, _n, _o, _p, _q, _r;
  const index = instances == null ? void 0 : instances.findIndex(
    ({ id }) => domId === id
  );
  const { vm } = instances[index];
  if (!vm) return;
  const appendTo = document.fullscreenElement || document.body;
  appendTo.removeChild((vm == null ? void 0 : vm.el) || (vm == null ? void 0 : vm.$el));
  instances.splice(index, 1);
  ((_a = vm == null ? void 0 : vm.component) == null ? void 0 : _a.proxy) && (vm.component.proxy.visible = false);
  const removedHeight = ((_b = vm == null ? void 0 : vm.el) == null ? void 0 : _b.offsetHeight) || ((_c = vm == null ? void 0 : vm.$el) == null ? void 0 : _c.offsetHeight);
  const len = instances.length;
  if (len < 1) return;
  for (let i = index; i < len; i++) {
    const pos = Number.parseInt(
      ((_g = (_f = (_e = (_d = instances[i]) == null ? void 0 : _d.vm) == null ? void 0 : _e.el) == null ? void 0 : _f.style) == null ? void 0 : _g.top) || ((_k = (_j = (_i = (_h = instances[i]) == null ? void 0 : _h.vm) == null ? void 0 : _i.$el) == null ? void 0 : _j.style) == null ? void 0 : _k.top),
      10
    ) - removedHeight - 16;
    ((_o = (_n = (_m = (_l = instances[i]) == null ? void 0 : _l.vm) == null ? void 0 : _m.component) == null ? void 0 : _n.props) == null ? void 0 : _o.offset) && (instances[i].vm.component.props.offset = pos);
    ((_r = (_q = (_p = instances[i]) == null ? void 0 : _p.vm) == null ? void 0 : _q._props) == null ? void 0 : _r.offset) && (instances[i].vm._props.offset = pos);
  }
};
const Toast = function(options) {
  let verticalOffset = options.offset || 60;
  instances.forEach(({ vm: vm2 }) => {
    var _a, _b;
    verticalOffset += (((_a = vm2 == null ? void 0 : vm2.el) == null ? void 0 : _a.offsetHeight) || ((_b = vm2 == null ? void 0 : vm2.$el) == null ? void 0 : _b.offsetHeight) || 0) + 20;
  });
  verticalOffset += 20;
  const id = `message_${seed += 1}`;
  const userOnClose = options.onClose;
  const props = {
    zIndex: 20 + seed,
    offset: verticalOffset,
    id,
    ...options,
    onClose: () => {
      Toast.close(id, userOnClose);
    }
  };
  const vm = createVNode(_sfc_main, props);
  let container;
  container = document.createElement("div");
  (vm == null ? void 0 : vm.props) && (vm.props.onDestroy = () => {
    render(null, container);
  });
  (vm == null ? void 0 : vm.data) && (vm.data.onDestroy = () => {
    render(null, container);
  });
  render(vm, container);
  instances.push({ id, vm });
  const appendTo = document.fullscreenElement || document.body;
  appendTo.appendChild(container.firstElementChild);
  return {
    close: () => {
      removeToast(id);
    }
  };
};
const typeToast = function(options, type) {
  const typeOption = {
    ...options,
    type
  };
  return Toast(typeOption);
};
function close(domId, userOnClose) {
  const index = instances == null ? void 0 : instances.findIndex(
    ({ id }) => domId === id
  );
  if (index === -1) return;
  const { vm } = instances[index];
  if (!vm) return;
  userOnClose == null ? void 0 : userOnClose(vm);
  removeToast(domId);
}
Toast.close = close;
Toast.info = (options) => typeToast(options, TOAST_TYPE.INFO);
Toast.success = (options) => typeToast(options, TOAST_TYPE.SUCCESS);
Toast.warning = (options) => typeToast(options, TOAST_TYPE.WARNING);
Toast.error = (options) => typeToast(options, TOAST_TYPE.ERROR);
const TUIToast = Toast;
export {
  TOAST_TYPE,
  TUIToast,
  close
};
