import { ref } from "vue";
const sizeButtonMap = {
  small: {
    width: "48px",
    height: "24px"
  },
  medium: {
    width: "64px",
    height: "32px"
  },
  big: {
    width: "80px",
    height: "40px"
  },
  large: {
    width: "96px",
    height: "48px"
  }
};
const sizeIconMap = {
  small: {
    width: "10px",
    height: "10px"
  },
  medium: {
    width: "16px",
    height: "16px"
  },
  big: {
    width: "20px",
    height: "20px"
  },
  large: {
    width: "40px",
    height: "40px"
  }
};
const ToastConfig = ref({
  showIcon: false,
  showClose: false
});
function setComponentTheme(componentName, value) {
  const root = document.documentElement;
  const themeProps = ["default", "hover", "active", "disabled"];
  themeProps.forEach((prop) => {
    let colorIndex = 6;
    if (prop === "disabled") {
      colorIndex = 2;
    } else if (prop === "hover") {
      colorIndex = 5;
    } else if (prop === "active") {
      colorIndex = 7;
    }
    root.style.setProperty(
      `--${componentName}-color-primary-${prop}`,
      `var(--uikit-color-${value}-${colorIndex})`
    );
  });
}
function setComponentShape(componentName, value) {
  const root = document.documentElement;
  root.style.setProperty(`--tui-${componentName}-round-radius`, value);
  root.style.setProperty(`--tui-${componentName}-rect-radius`, value);
  root.style.setProperty(`--tui-${componentName}-circle-radius`, value);
}
function setComponentSize(componentName, value) {
  const root = document.documentElement;
  if (componentName === "button") {
    root.style.setProperty(`--tui-${componentName}-small-width`, sizeButtonMap[value].width);
    root.style.setProperty(`--tui-${componentName}-small-height`, sizeButtonMap[value].height);
    root.style.setProperty(`--tui-${componentName}-medium-width`, sizeButtonMap[value].width);
    root.style.setProperty(`--tui-${componentName}-medium-height`, sizeButtonMap[value].height);
    root.style.setProperty(`--tui-${componentName}-big-width`, sizeButtonMap[value].width);
    root.style.setProperty(`--tui-${componentName}-big-height`, sizeButtonMap[value].height);
    root.style.setProperty(`--tui-${componentName}-large-width`, sizeButtonMap[value].width);
    root.style.setProperty(`--tui-${componentName}-large-height`, sizeButtonMap[value].height);
  } else if (componentName === "icon") {
    root.style.setProperty(`--tui-${componentName}-default-width`, sizeIconMap[value].width);
    root.style.setProperty(`--tui-${componentName}-default-height`, sizeIconMap[value].height);
  }
}
function setIconShow(componentName, value) {
  console.log(componentName, value);
  ToastConfig.value.showIcon = value;
}
function setCloseShow(componentName, value) {
  console.log(componentName, value);
  ToastConfig.value.showClose = value;
}
function useComponent() {
  return {
    setComponentTheme,
    setComponentShape,
    setComponentSize,
    setIconShow,
    setCloseShow,
    ToastConfig
  };
}
export {
  useComponent
};
