var __defProp = Object.defineProperty;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __publicField = (obj, key, value) => __defNormalProp(obj, typeof key !== "symbol" ? key + "" : key, value);
const colorMap = {
  "--text-color-link": "var(--uikit-color-theme-6)",
  "--text-color-link-hover": "var(--uikit-color-theme-5)",
  "--text-color-link-disabled": "var(--uikit-color-theme-2)",
  "--bg-color-bubble-own": "var(--uikit-color-theme-7)",
  "--list-color-focused": "var(--uikit-color-theme-2)",
  "--button-color-primary-default": "var(--uikit-color-theme-6)",
  "--button-color-primary-hover": "var(--uikit-color-theme-5)",
  "--button-color-primary-active": "var(--uikit-color-theme-7)",
  "--button-color-primary-disabled": "var(--uikit-color-theme-2)",
  "--checkbox-color-selected": "var(--uikit-color-theme-5)",
  "--toast-color-default": "var(--uikit-color-theme-2)",
  "--switch-color-on": "var(--uikit-color-theme-5)",
  "--slider-color-filled": "var(--uikit-color-theme-5)"
};
class ThemeColorGenerator {
  static hexToHSL(hex) {
    hex = hex.replace("#", "");
    const r = parseInt(hex.substring(0, 2), 16) / 255;
    const g = parseInt(hex.substring(2, 4), 16) / 255;
    const b = parseInt(hex.substring(4, 6), 16) / 255;
    const max = Math.max(r, g, b);
    const min = Math.min(r, g, b);
    let h = 0;
    let s = 0;
    const l = (max + min) / 2;
    if (max !== min) {
      const d = max - min;
      s = l > 0.5 ? d / (2 - max - min) : d / (max + min);
      switch (max) {
        case r:
          h = (g - b) / d + (g < b ? 6 : 0);
          break;
        case g:
          h = (b - r) / d + 2;
          break;
        case b:
          h = (r - g) / d + 4;
          break;
      }
      h /= 6;
    }
    return { h: h * 360, s: s * 100, l: l * 100 };
  }
  static HSLToHex(h, s, l) {
    l /= 100;
    const a = s * Math.min(l, 1 - l) / 100;
    const f = (n) => {
      const k = (n + h / 30) % 12;
      const color = l - a * Math.max(Math.min(k - 3, 9 - k, 1), -1);
      return Math.round(255 * color).toString(16).padStart(2, "0");
    };
    return `#${f(0)}${f(8)}${f(4)}`;
  }
  static generateColorVariations(baseColor) {
    const { h, s, l } = this.hexToHSL(baseColor);
    const variations = [];
    for (let i = 1; i <= 10; i++) {
      let newL = l;
      let newS = s;
      if (i <= 3) {
        newL = l + (100 - l) * (4 - i) / 3;
        newS = s * (4 - i) / 3;
      } else if (i >= 8) {
        newL = l * (11 - i) / 3;
        newS = s + (100 - s) * (i - 7) / 3;
      }
      variations.push(this.HSLToHex(h, newS, newL));
    }
    return variations;
  }
  static updateCSSVariables(variables, baseColor) {
    const root = document.documentElement;
    const colorVariations = this.generateColorVariations(baseColor);
    colorVariations.forEach((color, index) => {
      root.style.setProperty(`--uikit-color-theme-${index + 1}`, color);
    });
    Object.entries(variables).forEach(([key, value]) => {
      if (value.includes("var(--uikit-color-theme-")) {
        const match = value.match(/var\(--uikit-color-theme-(\d+)\)/);
        if (match) {
          const index = parseInt(match[1]) - 1;
          root.style.setProperty(key, colorVariations[index]);
        }
      }
    });
  }
  static applyThemeColor(baseColor) {
    if (!baseColor.match(/^#[0-9A-Fa-f]{6}$/)) {
      console.warn(`Invalid color format: ${baseColor}, using default color`);
      return;
    }
    this.updateCSSVariables(colorMap, baseColor);
  }
  static watchThemeColor() {
    const observer = new MutationObserver((mutations) => {
      mutations.forEach((mutation) => {
        if (mutation.type === "attributes" && mutation.attributeName === "style") {
          const primaryColor = getComputedStyle(document.documentElement).getPropertyValue("--primary-color").trim();
          if (primaryColor) {
            this.applyThemeColor(primaryColor);
          }
        }
      });
    });
    observer.observe(document.documentElement, {
      attributes: true,
      attributeFilter: ["style"]
    });
  }
}
__publicField(ThemeColorGenerator, "COLOR_TYPES", ["theme", "green", "red", "orange"]);
__publicField(ThemeColorGenerator, "DEFAULT_COLOR", "theme");
export {
  ThemeColorGenerator
};
